import React from 'react';
import ButtonGroup from './ButtonGroup';
import IconButton from './IconButton';

class LinkControls extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      urlValue: '',
    };

    this.onURLChange = (event) => this.setState({ urlValue: event.target.value });
    this.confirmLink = (event) => {
      event.preventDefault();
      this.props.confirmLink(this.state.urlValue);
      $('.ui.linkify.modal').modal('hide');
      this.setState({
        urlValue: '',
      });
    };
    this.removeLink = () => {
      this.props.removeLink()
    };
  }

  promptForLink() {
    const { editorState } = this.props;
    const selection = editorState.getSelection();
    if (!selection.isCollapsed()) {
      $('.ui.linkify.modal').modal('show');
      this.setState({
        urlValue: '',
      }, () => {
        setTimeout(() => this.refs.url.focus(), 0);
      });
    }
  }

  hidePrompt(event) {
    event.preventDefault();
    $('.ui.linkify.modal').modal('hide');
  }

  onLinkInputKeyDown(event) {
    if (event.which === 13) {
      this.confirmLink(event);
    }
  }

  render() {
    return (
      <ButtonGroup>

        <div className="ui small linkify modal">
          <i className="close icon" />
          <div className="header">Insert Link</div>

          <div className="content">
            <div className="ui fluid input">
              <input
                onChange={this.onURLChange}
                ref="url"
                type="text"
                value={this.state.urlValue}
                onKeyDown={this.onLinkInputKeyDown.bind(this)}
                placeholder="http://www.example.com"
              />
            </div>
          </div>

          <div className="actions">
            <button
              type="button"
              className="ui icon button"
              onMouseDown={this.hidePrompt.bind(this)}
            >
              <i className="close icon" />
            </button>
            <button
              type="button"
              className="ui primary icon button"
              onMouseDown={this.confirmLink}
            >
              <i className="check icon" />
            </button>
          </div>
        </div>

        <IconButton
          onToggle={this.promptForLink.bind(this)}
          icon="linkify"
          active={false}
        />
        <IconButton
          onToggle={this.removeLink}
          icon="unlink"
          active={false}
        />
      </ButtonGroup>
    );
  }
}

export default LinkControls;
